@@ -34,17 +34,21 @@ from typing import TypeVar
 from typing import Union
 
 import arrow
-import httpx
+import requests
 from feedgen.feed import FeedGenerator
+from outdated import check_outdated
 from PIL import Image
 from rich import print as rprint
 from rich import traceback
 from rich.logging import RichHandler
 from yt_dlp import YoutubeDL
 
+from . import __display_name__
+from . import __package_name__
 from . import __version__
 
 traceback.install(show_locals=True)
+logger = logging.getLogger("VideoPlaylist2Podcast")
 
 CFG = TypeVar("CFG", bound="Configuration")
 
@@ -224,7 +228,6 @@ def main() -> None:
 
     config = Configuration(config_file_name=args.config_file)
 
-    logger = logging.getLogger("VideoPlaylist2Podcast")
     logger.setLevel(logging.DEBUG)
 
     std_out_formatter = logging.Formatter(
@@ -236,7 +239,12 @@ def main() -> None:
     std_out_handler.setLevel(config.log_level)
     logger.addHandler(std_out_handler)
 
-    logger.info("Welcome to Playlist2Podcast version %s", __version__)
+    rprint(
+        f"[cyan]Welcome to [green][bold]{__display_name__}[/bold][cyan] "
+        f"version [yellow]{__version__}"
+    )
+
+    check_updates()
 
     feed = FeedGenerator()
     feed.author(name="Marvin", email="marvin@example.com")
@@ -246,9 +254,7 @@ def main() -> None:
     feed.description("Marvin's Youtube Playlist Podcast")
 
     for current_play_list in config.play_lists:
-        logger.info(
-            "Downloading info for videos on playlist: %s", current_play_list["url"]
-        )
+        rprint(f"Downloading info for videos on playlist: {current_play_list['url']}")
 
         download_options = YDL_DL_OPTS
         download_options["playlistend"] = config.number_of_episodes * 3
@@ -269,11 +275,10 @@ def main() -> None:
                 video_original_url=video["original_url"],
                 include_filters=cast(List[str], current_play_list["include"]),
                 exclude_filters=cast(List[str], current_play_list["exclude"]),
-                logger=logger,
             )
         ]
 
-        add_episodes(config, downloader, feed, logger, videos_to_download)
+        add_episodes(config, downloader, feed, videos_to_download)
 
     feed.rss_file(
         f"{config.publish_dir}/feed.rss",
@@ -288,7 +293,6 @@ def is_video_included(
     video_original_url: str,
     include_filters: List[str],
     exclude_filters: List[str],
-    logger: logging.Logger,
 ) -> bool:
     """Checks video title against include and exclude filters to determine if
     video should be considered for adding to podcast or not.
@@ -300,12 +304,13 @@ def is_video_included(
     :param exclude_filters: Lost of regex patterns actins as exclude filters.
         If one exclude filter matches, video will be skipped, even if there is a
         matching include filter. I.e. exclude > include
-    :param logger: Logger to show progress on screen
     :return: True if video should be considered for adding and False if video should
         be skipped based on filters.
     """
     logger.debug(
-        f"Filtering: Checking video: '{video_title}' at '{video_original_url}'"
+        "Filtering: Checking video: '%s' at '%s'",
+        video_title,
+        video_original_url,
     )
 
     should_include_video = False
@@ -323,11 +328,11 @@ def is_video_included(
         for include_filter in include_filters:
             regex = re.compile(include_filter)
             if title_len and regex.match(video_title):
-                logger.debug(f"Filtering: Include filter '{include_filter}' matches")
+                logger.debug("Filtering: Include filter '%s' matches", include_filter)
                 should_include_video = True
                 break
             if url_len and regex.match(video_original_url):
-                logger.debug(f"Filtering: Include filter '{include_filter}' matches")
+                logger.debug("Filtering: Include filter '%s' matches", include_filter)
                 should_include_video = True
                 break
 
@@ -335,15 +340,17 @@ def is_video_included(
         for exclude_filter in exclude_filters:
             regex = re.compile(exclude_filter)
             if title_len and regex.match(video_title):
-                logger.debug(f"Filtering: Exclude filter '{exclude_filter}' matches")
+                logger.debug("Filtering: Exclude filter '%s' matches", exclude_filter)
                 should_include_video = False
                 break
             if url_len and regex.match(video_original_url):
-                logger.debug(f"Filtering: Exclude filter '{exclude_filter}' matches")
+                logger.debug("Filtering: Exclude filter '%s' matches", exclude_filter)
                 should_include_video = False
                 break
 
-    logger.debug(f"Filtering: Video '{video_title}' included? {should_include_video}")
+    logger.debug(
+        "Filtering: Video '%s' included? %s", video_title, should_include_video
+    )
 
     return should_include_video
 
@@ -352,7 +359,6 @@ def add_episodes(
     config: Configuration,
     downloader: YoutubeDL,
     feed: FeedGenerator,
-    logger: logging.Logger,
     play_list_info: List[Dict[str, str]],
 ) -> None:
     """Iterates through play list info and decides which videos to process and
@@ -361,7 +367,6 @@ def add_episodes(
     :param config: Contains program configuration
     :param downloader: Youtube-dl object to download and process videos
     :param feed: RSS feed to add episodes to
-    :param logger: Logger to show progress on screen
     :param play_list_info: List of info dicts for each video in the playlist
     :return: None
     """
@@ -387,13 +392,11 @@ def add_episodes(
                 f"{config.podcast_host}/{config.media_dir}/{feed_entry.id()}.opus"
             )
             if not os.path.isfile(local_audio_file):
-                logger.info(
-                    "Downloading episode with id %s and length %s uploaded on %s with "
-                    "title %s ",
-                    feed_entry.id(),
-                    datetime.timedelta(seconds=int(video["duration"])),
-                    feed_entry.published().strftime("%Y-%m-%d"),
-                    feed_entry.title(),
+                rprint(
+                    f"Downloading episode with id {feed_entry.id()} "
+                    f"and length {datetime.timedelta(seconds=int(video['duration']))} "
+                    f"uploaded on {feed_entry.published().strftime('%Y-%m-%d')} with "
+                    f"title [green]{feed_entry.title()}"
                 )
                 downloader.download([video["webpage_url"]])
             feed_entry.enclosure(host_audio_file, 0, "audio/ogg")
@@ -423,7 +426,7 @@ def add_episodes(
             try:
                 os.remove(f'{config.publish_dir}/{config.media_dir}/{video["id"]}.opus')
                 os.remove(f'{config.publish_dir}/{config.media_dir}/{video["id"]}.jpg')
-                logger.info(
+                logger.debug(
                     "Removed old files for episode with id %s from %s with title %s",
                     video["id"],
                     video["upload_date"],
@@ -438,6 +441,32 @@ def add_episodes(
                 )
 
 
+def check_updates() -> None:
+    """Check if there is a newer version of MastodonAmnesia available on
+    PyPI."""
+    is_outdated = False
+    try:
+        is_outdated, pypi_version = check_outdated(
+            package=__package_name__,
+            version=__version__,
+        )
+
+        logger.debug(
+            "Checked for updates for %s version %s", __package_name__, __version__
+        )
+        logger.debug("Is outdated: %s (PyPi version: %s)", is_outdated, pypi_version)
+
+        if is_outdated:
+            rprint(
+                f"[bold][red]!!! New version of {__display_name__} ({pypi_version}) "
+                f"is available on PyPI.org !!!\n"
+            )
+    except ValueError:
+        rprint(
+            "[yellow]Notice - Your version is higher than last published version on PyPI"
+        )
+
+
 def get_thumbnail(config: Configuration, video_id: str, video: Dict[str, Any]) -> str:
     """Gets the highest quality thumbnail out of the video dict, converts it to
     JPG and returns the filename of the converted file.
@@ -454,7 +483,7 @@ def get_thumbnail(config: Configuration, video_id: str, video: Dict[str, Any]) -
     publish_image = f"{video_id}.jpg"
     publish_image_path = f"{config.publish_dir}/{config.media_dir}/{publish_image}"
     if not os.path.isfile(publish_image_path):
-        remote_image = httpx.get(image_url)
+        remote_image = requests.get(image_url)
         with open(local_image, "wb") as file:
             file.write(remote_image.content)
         thumbnail_wip = Image.open(local_image)
